/* Onpub (TM)
 * Copyright (C) 2010 Onpub Co. <http://onpubco.com/>
 * Author: Corey H.M. Taylor <corey@onpubco.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; version 2.
 */

YUI(
{
  base: "../yui/build/",
  timeout: 10000
}
).use("node", "node-menunav", function(Y)
{
  // Load and display the menubar.
  var menu = Y.one("#onpub-menubar");
  menu.plug(Y.Plugin.NodeMenuNav);
  menu.get("ownerDocument").get("documentElement").removeClass("yui3-loading");

  // Event handler functions.
  function moveUp(e, list)
  {
    var options = list.get("options");
    var index = list.get("selectedIndex");
    var node;
    var selected = null;

    if ((index == 0) || (index == -1)) {
      return;
    }

    node = options.item(index).remove();
    list.insertBefore(node, options.item(index - 1));
  }

  function moveDown(e, list)
  {
    var options = list.get("options");
    var index  = list.get("selectedIndex");
    var node;

    if ((index == -1)) {
      return;
    }

    node = options.item(index).remove();
    list.insertBefore(node, options.item(index + 2));
  }

  function remove(e, list)
  {
    var options = list.get("options");
    var index  = list.get("selectedIndex");

    if ((index == -1)) {
      return;
    }

    for (var i = 0; i < options.size(); i++) {
      option = options.item(i);

      if (option.get("selected")) {
        option.remove();
      }
    }

    if (list.get("length") == 0) {
      list.insert(Y.Node.create('<option value="">None</option>'), 0);
    }
  }

  function add(e, options, list)
  {
    var option;
    var listOptions;

    for (var i = 0; i < options.size(); i++) {
      option = options.item(i);

      if (option.get("selected")) {
        listOptions = list.get("options");

        if (listOptions.item(0).get("text") == "None") {
          listOptions.item(0).remove();
        }

        option = option.cloneNode(true);
        option.set("selected", true);
        list.append(option);
      }
    }
  }

  function selectAll(e, list)
  {
    var options = list.get("options");
    var option;

    for (var i = 0; i < options.size(); i++) {
      option = options.item(i);
      option.set("selected", true);
    }
  }

  function confirmDelete(e)
  {
    var result = false;
    result = confirm( "Are you sure?");

    if (!result) {
      e.preventDefault();
    }
  }

  function confirmNewPage(e, action)
  {
    var result = false;
    result = confirm( "Are you sure?");

    if (result) {
      action();
    }
  }

  function deleteArticle(e, articleID)
  {
    window.location.replace("index.php?onpub=DeleteArticle&articleIDs[]=" + articleID.get("value"));
  }

  function performAction(e, articleIDs)
  {
    var action = "index.php?onpub=" + e.target.get("value");
    var item;

    for (var i = 0; i < articleIDs.size(); i++) {
      item = articleIDs.item(i);

      if (item.get("checked")) {
        action += "&articleIDs[]=" + item.get("value");
      }
    }

    window.location.replace(action);
  }

  // Register event handlers.
  if (Y.one("#articles")) {
    Y.on("click", moveUp, "#moveUp", null, Y.one("#articles"));
    Y.on("click", moveDown, "#moveDown", null, Y.one("#articles"));
    Y.on("click", remove, "#remove", null, Y.one("#articles"));
    Y.on("click", selectAll, "#selectAll", null, Y.one("#articles"));
  }

  if (Y.one("#existing") && Y.one("#sections")) {
    Y.on("click", add, "#add", null, Y.all("#existing option"), Y.one("#sections"));
    Y.on("click", moveUp, "#moveUp", null, Y.one("#sections"));
    Y.on("click", moveDown, "#moveDown", null, Y.one("#sections"));
    Y.on("click", remove, "#remove", null, Y.one("#sections"));
    Y.on("click", selectAll, "#selectAll", null, Y.one("#sections"));
  }

  if (Y.one("#confirmDelete")) {
    Y.on("click", confirmDelete, "#confirmDelete");
  }

  if (Y.one("#deleteArticle")) {
    Y.on("click", deleteArticle, "#deleteArticle", null, Y.one("#articleID"));
  }

  if (Y.one("#actions")) {
    Y.on("change", performAction, "#actions", null, Y.all("#articleIDs"));
  }

  if (Y.one("a.cke_button_newpage")) {
    var node = Y.one("a.cke_button_newpage");
    var action = node.get("onclick");

    node.set("onclick", null);

    Y.on("click", confirmNewPage, node, null, action);
  }
}
);

function deleteImage()
{
    var result = false;

    result = confirm( "Are you sure?");

    if ( result ) {
        document.forms[0].onpub.value = "DeleteImageProcess";
        document.forms[0].submit();
    }
}

function deleteSection()
{
    var result = false;

    result = confirm( "Are you sure?");

    if ( result ) {
        document.forms[0].onpub.value = "DeleteSectionProcess";
        document.forms[0].submit();
    }
}

function deleteWebsite()
{
    var result = false;

    result = confirm( "Are you sure?");

    if ( result ) {
        document.forms[0].onpub.value = "DeleteWebsiteProcess";
        document.forms[0].submit();
    }
}
